Module pattern

Module pattern 

Regex pattern validation rule derived from XSD pattern facets.

Uses the regex crate to compile and match patterns. Patterns are anchored (full-string match) to match XSD semantics where the pattern must match the entire value.

Structs

PatternRule
Validates a string against a compiled regular expression (full-string match).